export declare type QueryFields<Fields> = Partial<Fields> & {
    id?: number;
    creator_id?: number;
    include?: {
        [key: string]: any;
    };
    searchField?: keyof Fields;
    q?: string;
    perpage?: number;
    page?: number;
    date_from?: string;
    date_to?: string;
};
export declare type ApiTokenFields = {
    secret_key: string;
    website: string;
    status: "active" | "deactive" | "trash";
    permissions: string;
    user_id: number;
};
export declare type ApiTokkenQuery = QueryFields<ApiTokenFields>;
export declare type MediaFields = {
    name: string;
    url: string;
    type: "unknown" | "image" | "audio" | "video" | "archive" | "document" | "pdf";
    mimetype: string;
    size: number;
};
export declare type MediaQuery = QueryFields<MediaFields>;
export declare type NotificationFields = {
    title: string;
    type: string;
    content: string;
    user_id: number;
    viewed_on?: string;
    expire_on?: string;
};
export declare type NotificationQuery = QueryFields<NotificationFields>;
export declare type OptionFields = {
    key: string;
    value: string;
};
export declare type OptionQuery = QueryFields<OptionFields>;
export declare type PostFields = {
    title: string;
    type: string;
    content?: string;
    parent_id?: number;
    slug?: string;
    excerpt?: string;
    status?: "trash" | "publish" | "private" | "protected" | "draft";
    thumbnail_id?: number;
};
export declare type PostQuery = QueryFields<PostFields>;
export interface PostCommentFields {
    post_id: number;
    content: string;
    user_id: number;
    status?: "trash" | "private" | "public";
    likes?: number;
    dislikes?: number;
    reply_id?: number;
}
export declare type PostCommentQuery = QueryFields<PostCommentFields>;
export interface PostMetaFields {
    post_id: number;
    key: string;
    value: string;
}
export declare type PostMetaQuery = QueryFields<PostMetaFields>;
export interface PostTermFields {
    post_id: number;
    terms: number[];
}
export declare type PostTermQuery = QueryFields<PostTermFields & {
    term_id: number;
}>;
export interface SessionFields {
    ua: string;
    ip: string;
    user_id: number;
}
export declare type SessionQuery = QueryFields<SessionFields & {
    sid: string;
    expire_on: any;
}>;
export interface TermFields {
    type: string;
    name: string;
    icon_id?: number;
    parent_id?: number;
    slug?: string;
    content?: string;
}
export declare type TermQuery = QueryFields<TermFields>;
export interface TranslateFields {
    key: string;
    content: string;
    language_id: number;
}
export declare type TranslateQuery = QueryFields<TranslateFields>;
export interface UserFields {
    firstname: string;
    email: string;
    password: string;
    role_id: number;
    lastname?: string;
    phone?: string;
    username?: string;
    status?: "active" | "deactive" | "panding" | "trash";
    photo_id?: number;
}
export declare type UserQuery = QueryFields<UserFields>;
export interface UserMetaFields {
    user_id: number;
    key: string;
    value: string;
}
export declare type UserMetaQuery = QueryFields<UserMetaFields>;
export interface UserRoleFields {
    name: string;
    permissions?: string;
    type?: "admin" | "user";
    status?: "active" | "deactive" | "trash";
    description?: string;
}
export declare type UserRoleQuery = QueryFields<UserRoleFields>;
export interface VerificationFields {
    user_id: number;
    expire_on?: any;
}
export declare type VerificationQuery = QueryFields<VerificationFields & {
    id: number;
    token: string;
    code: string;
}>;
/**
 * Model ApiToken
 *
 */
export declare type ApiToken = {
    id: number;
    secret_key: string;
    website: string;
    status: ApiTokenStatus;
    permissions: string;
    created_at: Date;
    updated_at: Date;
    user_id: number | null;
    creator_id: number | null;
};
/**
 * Model UserRole
 *
 */
export declare type UserRole = {
    id: number;
    name: string;
    type: UserRoleTypes | null;
    status: UserRoleStatus | null;
    description: string | null;
    permissions: string | null;
    updated_at: Date | null;
    created_at: Date | null;
    creator_id: number | null;
};
/**
 * Model User
 *
 */
export declare type User = {
    id: number;
    firstname: string | null;
    lastname: string | null;
    email: string;
    phone: string | null;
    password: string;
    username: string | null;
    status: UserStatusTypes | null;
    created_at: Date | null;
    updated_at: Date;
    photo_id: number | null;
    role_id: number;
    creator_id: number | null;
};
/**
 * Model UserMeta
 *
 */
export declare type UserMeta = {
    id: number;
    user_id: number;
    key: string;
    value: string | null;
    created_at: Date | null;
    updated_at: Date;
};
/**
 * Model Session
 *
 */
export declare type Session = {
    id: number;
    sid: string;
    ua: string;
    ip: string;
    expire_on: string;
    created_at: Date | null;
    updated_at: Date;
    user_id: number | null;
};
/**
 * Model Verification
 *
 */
export declare type Verification = {
    id: number;
    token: string;
    code: string;
    expire_on: string;
    created_at: Date | null;
    updated_at: Date;
    user_id: number | null;
};
/**
 * Model Notification
 *
 */
export declare type Notification = {
    id: number;
    type: string;
    title: string;
    content: string | null;
    viewed_on: string;
    expire_on: string;
    created_at: Date | null;
    updated_at: Date;
    user_id: number;
};
/**
 * Model Post
 *
 */
export declare type Post = {
    id: number;
    type: string;
    title: string;
    content: string | null;
    excerpt: string | null;
    slug: string;
    status: PostStatusTypes;
    created_at: Date;
    updated_at: Date;
    thumbnail_id: number | null;
    parent_id: number | null;
    creator_id: number | null;
};
/**
 * Model PostMeta
 *
 */
export declare type PostMeta = {
    id: number;
    post_id: number;
    key: string;
    value: string;
    created_at: Date | null;
    updated_at: Date;
};
/**
 * Model PostTerm
 *
 */
export declare type PostTerm = {
    id: number;
    post_id: number;
    term_id: number;
    created_at: Date | null;
    updated_at: Date;
};
/**
 * Model Term
 *
 */
export declare type Term = {
    id: number;
    type: string;
    name: string;
    slug: string;
    icon_id: number | null;
    content: string | null;
    parent_id: number | null;
    created_at: Date;
    updated_at: Date;
    creator_id: number | null;
};
/**
 * Model PostComment
 *
 */
export declare type PostComment = {
    id: number;
    content: string;
    status: PostCommentStatus;
    likes: number | null;
    dislikes: number | null;
    created_at: Date;
    updated_at: Date;
    post_id: number;
    reply_id: number | null;
    user_id: number | null;
};
/**
 * Model Translate
 *
 */
export declare type Translate = {
    id: number;
    key: string;
    content: string | null;
    language_id: number;
    creator_id: number | null;
};
/**
 * Model Option
 *
 */
export declare type Option = {
    id: number;
    key: string;
    value: string;
    created_at: Date;
    updated_at: Date;
    creator_id: number | null;
};
/**
 * Model Media
 *
 */
export declare type Media = {
    id: number;
    name: string;
    url: string;
    type: MediaType;
    mimetype: string;
    size: number;
    created_at: Date | null;
    updated_at: Date;
    creator_id: number | null;
};
export declare enum ApiTokenStatus {
    active = 0,
    deactive = 1,
    trash = 2
}
export declare enum UserRoleTypes {
    admin = 0,
    user = 1
}
export declare enum UserRoleStatus {
    active = 0,
    deactive = 1,
    trash = 2
}
export declare enum UserStatusTypes {
    active = 0,
    deactive = 1,
    panding = 2,
    trash = 3
}
export declare enum PostStatusTypes {
    publish = 0,
    private = 1,
    protected = 2,
    draft = 3,
    trash = 4
}
export declare enum PostCommentStatus {
    public = 0,
    private = 1,
    trash = 2
}
export declare enum MediaType {
    unknown = 0,
    image = 1,
    audio = 2,
    video = 3,
    archive = 4,
    document = 5,
    pdf = 6
}
